WifiStaIfaceRequest

Enum WifiStaIfaceRequest 

pub enum WifiStaIfaceRequest {
    GetName {
        responder: WifiStaIfaceGetNameResponder,
    },
    SetScanOnlyMode {
        payload: WifiStaIfaceSetScanOnlyModeRequest,
        responder: WifiStaIfaceSetScanOnlyModeResponder,
    },
    SetMacAddress {
        mac_addr: [u8; 6],
        responder: WifiStaIfaceSetMacAddressResponder,
    },
    GetApfPacketFilterSupport {
        responder: WifiStaIfaceGetApfPacketFilterSupportResponder,
    },
    InstallApfPacketFilter {
        payload: WifiStaIfaceInstallApfPacketFilterRequest,
        responder: WifiStaIfaceInstallApfPacketFilterResponder,
    },
    ReadApfPacketFilterData {
        responder: WifiStaIfaceReadApfPacketFilterDataResponder,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: WifiStaIfaceControlHandle, method_type: MethodType, }, }

Variants



GetName

Get the name of this iface.



SetScanOnlyMode



SetMacAddress

Sets the MAC address of the client interface. To reset the MAC address to the default/factory value, use the GetFactoryMacAddress method to retrieve the factory address and pass it to this method.

Fields

mac_addr: [u8; 6]


GetApfPacketFilterSupport



InstallApfPacketFilter

Installs an APF program, replacing an existing program if present. This method does not enable the program. Rather, the upstream users expect that the program will be enabled and disabled by the platform in response to other signals, like suspension.



ReadApfPacketFilterData

Fetches a consistent snapshot of the entire APF program and working memory buffer and returns it to the host. The returned buffer contains both code and data. Its length must match the most recently returned GetApfPacketFilterSupport().max_filter_length.

While the snapshot is being fetched, the APF interpreter must not execute and all incoming packets must be passed to the host as if there was no APF program installed.



#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

method_type: MethodType

Implementations