pub struct KeyMgmtMask(/* private fields */);Implementations
Sourceimpl KeyMgmtMask
impl KeyMgmtMask
pub const WPA_EAP: KeyMgmtMask
pub const WPA_PSK: KeyMgmtMask
pub const NONE: KeyMgmtMask
pub const IEEE8021_X: KeyMgmtMask
pub const FT_EAP: KeyMgmtMask
pub const FT_PSK: KeyMgmtMask
pub const OSEN: KeyMgmtMask
pub const WPA_EAP_SHA256: KeyMgmtMask
pub const WPA_PSK_SHA256: KeyMgmtMask
pub const SAE: KeyMgmtMask
pub const SUITE_B_192: KeyMgmtMask
pub const OWE: KeyMgmtMask
pub const DPP: KeyMgmtMask
pub const WAPI_PSK: KeyMgmtMask
pub const WAPI_CERT: KeyMgmtMask
pub const FILS_SHA256: KeyMgmtMask
pub const FILS_SHA384: KeyMgmtMask
pub const PASN: KeyMgmtMask
Sourceimpl KeyMgmtMask
impl KeyMgmtMask
Sourcepub const fn empty() -> KeyMgmtMask
pub const fn empty() -> KeyMgmtMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> KeyMgmtMask
pub const fn all() -> KeyMgmtMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<KeyMgmtMask>
pub const fn from_bits(bits: u32) -> Option<KeyMgmtMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> KeyMgmtMask
pub const fn from_bits_truncate(bits: u32) -> KeyMgmtMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> KeyMgmtMask
pub const fn from_bits_retain(bits: u32) -> KeyMgmtMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<KeyMgmtMask>
pub fn from_name(name: &str) -> Option<KeyMgmtMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: KeyMgmtMask) -> bool
pub const fn intersects(&self, other: KeyMgmtMask) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: KeyMgmtMask) -> bool
pub const fn contains(&self, other: KeyMgmtMask) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: KeyMgmtMask)
pub fn insert(&mut self, other: KeyMgmtMask)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: KeyMgmtMask)
pub fn remove(&mut self, other: KeyMgmtMask)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: KeyMgmtMask)
pub fn toggle(&mut self, other: KeyMgmtMask)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: KeyMgmtMask, value: bool)
pub fn set(&mut self, other: KeyMgmtMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: KeyMgmtMask) -> KeyMgmtMask
pub const fn intersection(self, other: KeyMgmtMask) -> KeyMgmtMask
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: KeyMgmtMask) -> KeyMgmtMask
pub const fn union(self, other: KeyMgmtMask) -> KeyMgmtMask
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: KeyMgmtMask) -> KeyMgmtMask
pub const fn difference(self, other: KeyMgmtMask) -> KeyMgmtMask
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: KeyMgmtMask) -> KeyMgmtMask
pub const fn symmetric_difference(self, other: KeyMgmtMask) -> KeyMgmtMask
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> KeyMgmtMask
pub const fn complement(self) -> KeyMgmtMask
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl KeyMgmtMask
impl KeyMgmtMask
Sourcepub const fn iter(&self) -> Iter<KeyMgmtMask> ⓘ
pub const fn iter(&self) -> Iter<KeyMgmtMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<KeyMgmtMask> ⓘ
pub const fn iter_names(&self) -> IterNames<KeyMgmtMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl KeyMgmtMask
impl KeyMgmtMask
pub fn from_bits_allow_unknown(bits: u32) -> KeyMgmtMask
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32