pub struct LinkLayerStats {
pub wme: Option<WmePacketStats>,
pub rssi_dbm: Option<i32>,
/* private fields */
}Fields
wme: Option<WmePacketStats>rssi_dbm: Option<i32>Trait Implementations
Sourceimpl Clone for LinkLayerStats
impl Clone for LinkLayerStats
Sourcefn clone(&self) -> LinkLayerStats
fn clone(&self) -> LinkLayerStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinkLayerStats
impl Debug for LinkLayerStats
Sourceimpl<D> Decode<LinkLayerStats, D> for LinkLayerStatswhere
D: ResourceDialect,
impl<D> Decode<LinkLayerStats, D> for LinkLayerStatswhere
D: ResourceDialect,
Sourcefn new_empty() -> LinkLayerStats
fn new_empty() -> LinkLayerStats
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for LinkLayerStats
impl Default for LinkLayerStats
Sourcefn default() -> LinkLayerStats
fn default() -> LinkLayerStats
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<LinkLayerStats, D> for &LinkLayerStatswhere
D: ResourceDialect,
impl<D> Encode<LinkLayerStats, D> for &LinkLayerStatswhere
D: ResourceDialect,
Sourceimpl PartialEq for LinkLayerStats
impl PartialEq for LinkLayerStats
impl Persistable for LinkLayerStats
impl StructuralPartialEq for LinkLayerStats
Sourceimpl TypeMarker for LinkLayerStats
impl TypeMarker for LinkLayerStats
Sourcetype Owned = LinkLayerStats
type Owned = LinkLayerStats
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for LinkLayerStats
impl ValueTypeMarker for LinkLayerStats
Sourcetype Borrowed<'a> = &'a LinkLayerStats
type Borrowed<'a> = &'a LinkLayerStats
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<LinkLayerStats as TypeMarker>::Owned,
) -> <LinkLayerStats as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<LinkLayerStats as TypeMarker>::Owned, ) -> <LinkLayerStats as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for LinkLayerStats
impl RefUnwindSafe for LinkLayerStats
impl Send for LinkLayerStats
impl Sync for LinkLayerStats
impl Unpin for LinkLayerStats
impl UnsafeUnpin for LinkLayerStats
impl UnwindSafe for LinkLayerStats