pub struct SchedScanMatchSet {
pub ssid: Option<Vec<u8>>,
pub bssid: Option<[u8; 6]>,
pub rssi_threshold: Option<i8>,
pub relative_rssi: Option<i8>,
pub rssi_adjust: Option<i8>,
/* private fields */
}Expand description
Matching criteria for PNO scan results.
Fields
ssid: Option<Vec<u8>>bssid: Option<[u8; 6]>rssi_threshold: Option<i8>relative_rssi: Option<i8>rssi_adjust: Option<i8>Trait Implementations
Sourceimpl Clone for SchedScanMatchSet
impl Clone for SchedScanMatchSet
Sourcefn clone(&self) -> SchedScanMatchSet
fn clone(&self) -> SchedScanMatchSet
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchedScanMatchSet
impl Debug for SchedScanMatchSet
Sourceimpl<D> Decode<SchedScanMatchSet, D> for SchedScanMatchSetwhere
D: ResourceDialect,
impl<D> Decode<SchedScanMatchSet, D> for SchedScanMatchSetwhere
D: ResourceDialect,
Sourcefn new_empty() -> SchedScanMatchSet
fn new_empty() -> SchedScanMatchSet
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for SchedScanMatchSet
impl Default for SchedScanMatchSet
Sourcefn default() -> SchedScanMatchSet
fn default() -> SchedScanMatchSet
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<SchedScanMatchSet, D> for &SchedScanMatchSetwhere
D: ResourceDialect,
impl<D> Encode<SchedScanMatchSet, D> for &SchedScanMatchSetwhere
D: ResourceDialect,
Sourceimpl PartialEq for SchedScanMatchSet
impl PartialEq for SchedScanMatchSet
Sourceimpl TypeMarker for SchedScanMatchSet
impl TypeMarker for SchedScanMatchSet
Sourcetype Owned = SchedScanMatchSet
type Owned = SchedScanMatchSet
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SchedScanMatchSet
impl ValueTypeMarker for SchedScanMatchSet
Sourcetype Borrowed<'a> = &'a SchedScanMatchSet
type Borrowed<'a> = &'a SchedScanMatchSet
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<SchedScanMatchSet as TypeMarker>::Owned,
) -> <SchedScanMatchSet as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<SchedScanMatchSet as TypeMarker>::Owned, ) -> <SchedScanMatchSet as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for SchedScanMatchSet
impl StructuralPartialEq for SchedScanMatchSet