#[repr(C)]pub struct SchedScanPlan {
pub interval_ms: u32,
pub iterations: u32,
}Expand description
Scan plan for PNO scanning.
Fields
interval_ms: u32iterations: u32Trait Implementations
Sourceimpl Clone for SchedScanPlan
impl Clone for SchedScanPlan
Sourcefn clone(&self) -> SchedScanPlan
fn clone(&self) -> SchedScanPlan
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchedScanPlan
impl Debug for SchedScanPlan
Sourceimpl<D> Decode<SchedScanPlan, D> for SchedScanPlanwhere
D: ResourceDialect,
impl<D> Decode<SchedScanPlan, D> for SchedScanPlanwhere
D: ResourceDialect,
Sourcefn new_empty() -> SchedScanPlan
fn new_empty() -> SchedScanPlan
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<SchedScanPlan, D> for &SchedScanPlanwhere
D: ResourceDialect,
impl<D> Encode<SchedScanPlan, D> for &SchedScanPlanwhere
D: ResourceDialect,
Sourceimpl Hash for SchedScanPlan
impl Hash for SchedScanPlan
Sourceimpl Ord for SchedScanPlan
impl Ord for SchedScanPlan
Sourcefn cmp(&self, other: &SchedScanPlan) -> Ordering
fn cmp(&self, other: &SchedScanPlan) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SchedScanPlan
impl PartialEq for SchedScanPlan
Sourceimpl PartialOrd for SchedScanPlan
impl PartialOrd for SchedScanPlan
Sourceimpl TypeMarker for SchedScanPlan
impl TypeMarker for SchedScanPlan
Sourcetype Owned = SchedScanPlan
type Owned = SchedScanPlan
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SchedScanPlan
impl ValueTypeMarker for SchedScanPlan
Sourcetype Borrowed<'a> = &'a SchedScanPlan
type Borrowed<'a> = &'a SchedScanPlan
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<SchedScanPlan as TypeMarker>::Owned,
) -> <SchedScanPlan as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<SchedScanPlan as TypeMarker>::Owned, ) -> <SchedScanPlan as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for SchedScanPlan
impl Eq for SchedScanPlan
impl Persistable for SchedScanPlan
impl StructuralPartialEq for SchedScanPlan