pub struct SchedScanRequest {
pub ssids: Option<Vec<Vec<u8>>>,
pub match_sets: Option<Vec<SchedScanMatchSet>>,
pub frequencies: Option<Vec<u32>>,
pub scan_plans: Option<Vec<SchedScanPlan>>,
pub sched_scan_multi: Option<bool>,
pub sched_scan_delay: Option<u32>,
pub ie: Option<Vec<u8>>,
pub relative_rssi: Option<i8>,
pub rssi_adjust: Option<i8>,
/* private fields */
}Fields
ssids: Option<Vec<Vec<u8>>>match_sets: Option<Vec<SchedScanMatchSet>>frequencies: Option<Vec<u32>>scan_plans: Option<Vec<SchedScanPlan>>sched_scan_multi: Option<bool>sched_scan_delay: Option<u32>ie: Option<Vec<u8>>relative_rssi: Option<i8>rssi_adjust: Option<i8>Trait Implementations
Sourceimpl Clone for SchedScanRequest
impl Clone for SchedScanRequest
Sourcefn clone(&self) -> SchedScanRequest
fn clone(&self) -> SchedScanRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchedScanRequest
impl Debug for SchedScanRequest
Sourceimpl<D> Decode<SchedScanRequest, D> for SchedScanRequestwhere
D: ResourceDialect,
impl<D> Decode<SchedScanRequest, D> for SchedScanRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> SchedScanRequest
fn new_empty() -> SchedScanRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for SchedScanRequest
impl Default for SchedScanRequest
Sourcefn default() -> SchedScanRequest
fn default() -> SchedScanRequest
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<SchedScanRequest, D> for &SchedScanRequestwhere
D: ResourceDialect,
impl<D> Encode<SchedScanRequest, D> for &SchedScanRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for SchedScanRequest
impl PartialEq for SchedScanRequest
Sourceimpl TypeMarker for SchedScanRequest
impl TypeMarker for SchedScanRequest
Sourcetype Owned = SchedScanRequest
type Owned = SchedScanRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SchedScanRequest
impl ValueTypeMarker for SchedScanRequest
Sourcetype Borrowed<'a> = &'a SchedScanRequest
type Borrowed<'a> = &'a SchedScanRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<SchedScanRequest as TypeMarker>::Owned,
) -> <SchedScanRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<SchedScanRequest as TypeMarker>::Owned, ) -> <SchedScanRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for SchedScanRequest
impl StructuralPartialEq for SchedScanRequest