pub struct SupplicantStaIfaceGetSignalPollResultsResponse {
pub current_rssi_dbm: Option<i32>,
pub tx_bitrate_mbps: Option<u32>,
pub rx_bitrate_mbps: Option<u32>,
pub frequency_mhz: Option<u32>,
/* private fields */
}Fields
current_rssi_dbm: Option<i32>tx_bitrate_mbps: Option<u32>rx_bitrate_mbps: Option<u32>frequency_mhz: Option<u32>Trait Implementations
Sourceimpl Clone for SupplicantStaIfaceGetSignalPollResultsResponse
impl Clone for SupplicantStaIfaceGetSignalPollResultsResponse
Sourcefn clone(&self) -> SupplicantStaIfaceGetSignalPollResultsResponse
fn clone(&self) -> SupplicantStaIfaceGetSignalPollResultsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<SupplicantStaIfaceGetSignalPollResultsResponse, D> for SupplicantStaIfaceGetSignalPollResultsResponsewhere
D: ResourceDialect,
impl<D> Decode<SupplicantStaIfaceGetSignalPollResultsResponse, D> for SupplicantStaIfaceGetSignalPollResultsResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> SupplicantStaIfaceGetSignalPollResultsResponse
fn new_empty() -> SupplicantStaIfaceGetSignalPollResultsResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for SupplicantStaIfaceGetSignalPollResultsResponse
impl Default for SupplicantStaIfaceGetSignalPollResultsResponse
Sourcefn default() -> SupplicantStaIfaceGetSignalPollResultsResponse
fn default() -> SupplicantStaIfaceGetSignalPollResultsResponse
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<SupplicantStaIfaceGetSignalPollResultsResponse, D> for &SupplicantStaIfaceGetSignalPollResultsResponsewhere
D: ResourceDialect,
impl<D> Encode<SupplicantStaIfaceGetSignalPollResultsResponse, D> for &SupplicantStaIfaceGetSignalPollResultsResponsewhere
D: ResourceDialect,
Sourceimpl PartialEq for SupplicantStaIfaceGetSignalPollResultsResponse
impl PartialEq for SupplicantStaIfaceGetSignalPollResultsResponse
Sourcefn eq(&self, other: &SupplicantStaIfaceGetSignalPollResultsResponse) -> bool
fn eq(&self, other: &SupplicantStaIfaceGetSignalPollResultsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for SupplicantStaIfaceGetSignalPollResultsResponse
impl TypeMarker for SupplicantStaIfaceGetSignalPollResultsResponse
Sourcetype Owned = SupplicantStaIfaceGetSignalPollResultsResponse
type Owned = SupplicantStaIfaceGetSignalPollResultsResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SupplicantStaIfaceGetSignalPollResultsResponse
impl ValueTypeMarker for SupplicantStaIfaceGetSignalPollResultsResponse
Sourcetype Borrowed<'a> = &'a SupplicantStaIfaceGetSignalPollResultsResponse
type Borrowed<'a> = &'a SupplicantStaIfaceGetSignalPollResultsResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<SupplicantStaIfaceGetSignalPollResultsResponse as TypeMarker>::Owned,
) -> <SupplicantStaIfaceGetSignalPollResultsResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<SupplicantStaIfaceGetSignalPollResultsResponse as TypeMarker>::Owned, ) -> <SupplicantStaIfaceGetSignalPollResultsResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for SupplicantStaIfaceGetSignalPollResultsResponse
impl StructuralPartialEq for SupplicantStaIfaceGetSignalPollResultsResponse