pub struct WifiStaIfaceInstallApfPacketFilterRequest {
pub program: Option<Vec<u8>>,
/* private fields */
}Fields
program: Option<Vec<u8>>Trait Implementations
Sourceimpl Clone for WifiStaIfaceInstallApfPacketFilterRequest
impl Clone for WifiStaIfaceInstallApfPacketFilterRequest
Sourcefn clone(&self) -> WifiStaIfaceInstallApfPacketFilterRequest
fn clone(&self) -> WifiStaIfaceInstallApfPacketFilterRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<WifiStaIfaceInstallApfPacketFilterRequest, D> for WifiStaIfaceInstallApfPacketFilterRequestwhere
D: ResourceDialect,
impl<D> Decode<WifiStaIfaceInstallApfPacketFilterRequest, D> for WifiStaIfaceInstallApfPacketFilterRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> WifiStaIfaceInstallApfPacketFilterRequest
fn new_empty() -> WifiStaIfaceInstallApfPacketFilterRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for WifiStaIfaceInstallApfPacketFilterRequest
impl Default for WifiStaIfaceInstallApfPacketFilterRequest
Sourcefn default() -> WifiStaIfaceInstallApfPacketFilterRequest
fn default() -> WifiStaIfaceInstallApfPacketFilterRequest
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<WifiStaIfaceInstallApfPacketFilterRequest, D> for &WifiStaIfaceInstallApfPacketFilterRequestwhere
D: ResourceDialect,
impl<D> Encode<WifiStaIfaceInstallApfPacketFilterRequest, D> for &WifiStaIfaceInstallApfPacketFilterRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for WifiStaIfaceInstallApfPacketFilterRequest
impl PartialEq for WifiStaIfaceInstallApfPacketFilterRequest
Sourcefn eq(&self, other: &WifiStaIfaceInstallApfPacketFilterRequest) -> bool
fn eq(&self, other: &WifiStaIfaceInstallApfPacketFilterRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for WifiStaIfaceInstallApfPacketFilterRequest
impl TypeMarker for WifiStaIfaceInstallApfPacketFilterRequest
Sourcetype Owned = WifiStaIfaceInstallApfPacketFilterRequest
type Owned = WifiStaIfaceInstallApfPacketFilterRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WifiStaIfaceInstallApfPacketFilterRequest
impl ValueTypeMarker for WifiStaIfaceInstallApfPacketFilterRequest
Sourcetype Borrowed<'a> = &'a WifiStaIfaceInstallApfPacketFilterRequest
type Borrowed<'a> = &'a WifiStaIfaceInstallApfPacketFilterRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<WifiStaIfaceInstallApfPacketFilterRequest as TypeMarker>::Owned,
) -> <WifiStaIfaceInstallApfPacketFilterRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<WifiStaIfaceInstallApfPacketFilterRequest as TypeMarker>::Owned, ) -> <WifiStaIfaceInstallApfPacketFilterRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for WifiStaIfaceInstallApfPacketFilterRequest
impl StructuralPartialEq for WifiStaIfaceInstallApfPacketFilterRequest