pub struct WifiStaIfaceReadApfPacketFilterDataResponse {
pub memory: Option<Vec<u8>>,
/* private fields */
}Fields
memory: Option<Vec<u8>>Trait Implementations
Sourceimpl Clone for WifiStaIfaceReadApfPacketFilterDataResponse
impl Clone for WifiStaIfaceReadApfPacketFilterDataResponse
Sourcefn clone(&self) -> WifiStaIfaceReadApfPacketFilterDataResponse
fn clone(&self) -> WifiStaIfaceReadApfPacketFilterDataResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<WifiStaIfaceReadApfPacketFilterDataResponse, D> for WifiStaIfaceReadApfPacketFilterDataResponsewhere
D: ResourceDialect,
impl<D> Decode<WifiStaIfaceReadApfPacketFilterDataResponse, D> for WifiStaIfaceReadApfPacketFilterDataResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> WifiStaIfaceReadApfPacketFilterDataResponse
fn new_empty() -> WifiStaIfaceReadApfPacketFilterDataResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for WifiStaIfaceReadApfPacketFilterDataResponse
impl Default for WifiStaIfaceReadApfPacketFilterDataResponse
Sourcefn default() -> WifiStaIfaceReadApfPacketFilterDataResponse
fn default() -> WifiStaIfaceReadApfPacketFilterDataResponse
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<WifiStaIfaceReadApfPacketFilterDataResponse, D> for &WifiStaIfaceReadApfPacketFilterDataResponsewhere
D: ResourceDialect,
impl<D> Encode<WifiStaIfaceReadApfPacketFilterDataResponse, D> for &WifiStaIfaceReadApfPacketFilterDataResponsewhere
D: ResourceDialect,
Sourceimpl PartialEq for WifiStaIfaceReadApfPacketFilterDataResponse
impl PartialEq for WifiStaIfaceReadApfPacketFilterDataResponse
Sourcefn eq(&self, other: &WifiStaIfaceReadApfPacketFilterDataResponse) -> bool
fn eq(&self, other: &WifiStaIfaceReadApfPacketFilterDataResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for WifiStaIfaceReadApfPacketFilterDataResponse
impl TypeMarker for WifiStaIfaceReadApfPacketFilterDataResponse
Sourcetype Owned = WifiStaIfaceReadApfPacketFilterDataResponse
type Owned = WifiStaIfaceReadApfPacketFilterDataResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WifiStaIfaceReadApfPacketFilterDataResponse
impl ValueTypeMarker for WifiStaIfaceReadApfPacketFilterDataResponse
Sourcetype Borrowed<'a> = &'a WifiStaIfaceReadApfPacketFilterDataResponse
type Borrowed<'a> = &'a WifiStaIfaceReadApfPacketFilterDataResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<WifiStaIfaceReadApfPacketFilterDataResponse as TypeMarker>::Owned,
) -> <WifiStaIfaceReadApfPacketFilterDataResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<WifiStaIfaceReadApfPacketFilterDataResponse as TypeMarker>::Owned, ) -> <WifiStaIfaceReadApfPacketFilterDataResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for WifiStaIfaceReadApfPacketFilterDataResponse
impl StructuralPartialEq for WifiStaIfaceReadApfPacketFilterDataResponse