pub enum WifiStaIfaceRequest {
GetName {
responder: WifiStaIfaceGetNameResponder,
},
SetScanOnlyMode {
payload: WifiStaIfaceSetScanOnlyModeRequest,
responder: WifiStaIfaceSetScanOnlyModeResponder,
},
SetMacAddress {
mac_addr: [u8; 6],
responder: WifiStaIfaceSetMacAddressResponder,
},
GetApfPacketFilterSupport {
responder: WifiStaIfaceGetApfPacketFilterSupportResponder,
},
InstallApfPacketFilter {
payload: WifiStaIfaceInstallApfPacketFilterRequest,
responder: WifiStaIfaceInstallApfPacketFilterResponder,
},
ReadApfPacketFilterData {
responder: WifiStaIfaceReadApfPacketFilterDataResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: WifiStaIfaceControlHandle,
method_type: MethodType,
},
}Variants
GetName
Get the name of this iface.
Fields
responder: WifiStaIfaceGetNameResponderSetScanOnlyMode
SetMacAddress
Sets the MAC address of the client interface. To reset the MAC address to the default/factory
value, use the GetFactoryMacAddress method to retrieve the factory address and pass it to
this method.
GetApfPacketFilterSupport
Fields
InstallApfPacketFilter
Installs an APF program, replacing an existing program if present. This method does not enable the program. Rather, the upstream users expect that the program will be enabled and disabled by the platform in response to other signals, like suspension.
Fields
responder: WifiStaIfaceInstallApfPacketFilterResponderReadApfPacketFilterData
Fetches a consistent snapshot of the entire APF program and working memory buffer and returns it to the host. The returned buffer contains both code and data. Its length must match the most recently returned GetApfPacketFilterSupport().max_filter_length.
While the snapshot is being fetched, the APF interpreter must not execute and all incoming packets must be passed to the host as if there was no APF program installed.
Fields
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
control_handle: WifiStaIfaceControlHandlemethod_type: MethodTypeImplementations
Sourceimpl WifiStaIfaceRequest
impl WifiStaIfaceRequest
pub fn into_get_name(self) -> Option<WifiStaIfaceGetNameResponder>
pub fn into_set_scan_only_mode( self, ) -> Option<(WifiStaIfaceSetScanOnlyModeRequest, WifiStaIfaceSetScanOnlyModeResponder)>
pub fn into_set_mac_address( self, ) -> Option<([u8; 6], WifiStaIfaceSetMacAddressResponder)>
pub fn into_get_apf_packet_filter_support( self, ) -> Option<WifiStaIfaceGetApfPacketFilterSupportResponder>
pub fn into_install_apf_packet_filter( self, ) -> Option<(WifiStaIfaceInstallApfPacketFilterRequest, WifiStaIfaceInstallApfPacketFilterResponder)>
pub fn into_read_apf_packet_filter_data( self, ) -> Option<WifiStaIfaceReadApfPacketFilterDataResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL