pub struct WifiStaIfaceProxy { /* private fields */ }Implementations
Sourceimpl WifiStaIfaceProxy
impl WifiStaIfaceProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.wlan.wlanix/WifiStaIface.
Sourcepub fn take_event_stream(&self) -> WifiStaIfaceEventStream
pub fn take_event_stream(&self) -> WifiStaIfaceEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_name(
&self,
) -> QueryResponseFut<WifiStaIfaceGetNameResponse, DefaultFuchsiaResourceDialect>
pub fn get_name( &self, ) -> QueryResponseFut<WifiStaIfaceGetNameResponse, DefaultFuchsiaResourceDialect>
Get the name of this iface.
pub fn set_scan_only_mode( &self, payload: WifiStaIfaceSetScanOnlyModeRequest, ) -> QueryResponseFut<WifiStaIfaceSetScanOnlyModeResult, DefaultFuchsiaResourceDialect>
Sourcepub fn set_mac_address(
&self,
mac_addr: &[u8; 6],
) -> QueryResponseFut<WifiStaIfaceSetMacAddressResult, DefaultFuchsiaResourceDialect>
pub fn set_mac_address( &self, mac_addr: &[u8; 6], ) -> QueryResponseFut<WifiStaIfaceSetMacAddressResult, DefaultFuchsiaResourceDialect>
Sets the MAC address of the client interface. To reset the MAC address to the default/factory
value, use the GetFactoryMacAddress method to retrieve the factory address and pass it to
this method.
pub fn get_apf_packet_filter_support( &self, ) -> QueryResponseFut<WifiStaIfaceGetApfPacketFilterSupportResult, DefaultFuchsiaResourceDialect>
Sourcepub fn install_apf_packet_filter(
&self,
payload: &WifiStaIfaceInstallApfPacketFilterRequest,
) -> QueryResponseFut<WifiStaIfaceInstallApfPacketFilterResult, DefaultFuchsiaResourceDialect>
pub fn install_apf_packet_filter( &self, payload: &WifiStaIfaceInstallApfPacketFilterRequest, ) -> QueryResponseFut<WifiStaIfaceInstallApfPacketFilterResult, DefaultFuchsiaResourceDialect>
Installs an APF program, replacing an existing program if present. This method does not enable the program. Rather, the upstream users expect that the program will be enabled and disabled by the platform in response to other signals, like suspension.
Sourcepub fn read_apf_packet_filter_data(
&self,
) -> QueryResponseFut<WifiStaIfaceReadApfPacketFilterDataResult, DefaultFuchsiaResourceDialect>
pub fn read_apf_packet_filter_data( &self, ) -> QueryResponseFut<WifiStaIfaceReadApfPacketFilterDataResult, DefaultFuchsiaResourceDialect>
Fetches a consistent snapshot of the entire APF program and working memory buffer and returns it to the host. The returned buffer contains both code and data. Its length must match the most recently returned GetApfPacketFilterSupport().max_filter_length.
While the snapshot is being fetched, the APF interpreter must not execute and all incoming packets must be passed to the host as if there was no APF program installed.