pub struct WifiStaIfaceSynchronousProxy { /* private fields */ }Implementations
Sourceimpl WifiStaIfaceSynchronousProxy
impl WifiStaIfaceSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<WifiStaIfaceEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<WifiStaIfaceEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn get_name(
&self,
___deadline: MonotonicInstant,
) -> Result<WifiStaIfaceGetNameResponse, Error>
pub fn get_name( &self, ___deadline: MonotonicInstant, ) -> Result<WifiStaIfaceGetNameResponse, Error>
Get the name of this iface.
pub fn set_scan_only_mode( &self, payload: WifiStaIfaceSetScanOnlyModeRequest, ___deadline: MonotonicInstant, ) -> Result<WifiStaIfaceSetScanOnlyModeResult, Error>
Sourcepub fn set_mac_address(
&self,
mac_addr: &[u8; 6],
___deadline: MonotonicInstant,
) -> Result<WifiStaIfaceSetMacAddressResult, Error>
pub fn set_mac_address( &self, mac_addr: &[u8; 6], ___deadline: MonotonicInstant, ) -> Result<WifiStaIfaceSetMacAddressResult, Error>
Sets the MAC address of the client interface. To reset the MAC address to the default/factory
value, use the GetFactoryMacAddress method to retrieve the factory address and pass it to
this method.
pub fn get_apf_packet_filter_support( &self, ___deadline: MonotonicInstant, ) -> Result<WifiStaIfaceGetApfPacketFilterSupportResult, Error>
Sourcepub fn install_apf_packet_filter(
&self,
payload: &WifiStaIfaceInstallApfPacketFilterRequest,
___deadline: MonotonicInstant,
) -> Result<WifiStaIfaceInstallApfPacketFilterResult, Error>
pub fn install_apf_packet_filter( &self, payload: &WifiStaIfaceInstallApfPacketFilterRequest, ___deadline: MonotonicInstant, ) -> Result<WifiStaIfaceInstallApfPacketFilterResult, Error>
Installs an APF program, replacing an existing program if present. This method does not enable the program. Rather, the upstream users expect that the program will be enabled and disabled by the platform in response to other signals, like suspension.
Sourcepub fn read_apf_packet_filter_data(
&self,
___deadline: MonotonicInstant,
) -> Result<WifiStaIfaceReadApfPacketFilterDataResult, Error>
pub fn read_apf_packet_filter_data( &self, ___deadline: MonotonicInstant, ) -> Result<WifiStaIfaceReadApfPacketFilterDataResult, Error>
Fetches a consistent snapshot of the entire APF program and working memory buffer and returns it to the host. The returned buffer contains both code and data. Its length must match the most recently returned GetApfPacketFilterSupport().max_filter_length.
While the snapshot is being fetched, the APF interpreter must not execute and all incoming packets must be passed to the host as if there was no APF program installed.